"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const node_pty_1 = require("node-pty");
const os_1 = tslib_1.__importDefault(require("os"));
exports.terminalEmulator = ({ cwd, onData, onStopProcessing, onExit }) => {
    const isWin = os_1.default.platform() === 'win32';
    /* istanbul ignore next */
    const reg = isWin ? /PS \w:[^>]*>/ : /bash-3\.2\$ ?$/;
    let regMatchCounter = 0;
    /* istanbul ignore next */
    const shell = isWin ? 'powershell.exe' : 'bash';
    process.env.FORCE_COLOR = true;
    const ptyProcess = node_pty_1.spawn(shell, [], {
        name: 'xterm-color',
        cols: 500,
        rows: 30,
        cwd,
        env: process.env,
    });
    ptyProcess.on('data', (data) => {
        if (reg.test(data)) {
            regMatchCounter += 1;
            /* istanbul ignore next */
            if (isWin && regMatchCounter <= 2) {
                // ignore first match on windows
                return;
            }
            regMatchCounter = 0;
            if (onStopProcessing) {
                onStopProcessing();
            }
            return;
        }
        onData(data);
    });
    ptyProcess.on('exit', () => {
        if (onExit) {
            onExit();
        }
    });
    return ptyProcess;
};
//# sourceMappingURL=index.js.map